from .searcher import Searcher
from .query import Query
from .sites import Site

def search(query: Query | str) -> list:
    """Wrapper around searcher.search"""
    s = Searcher()
    return s.search(query)

def search_index_of(folder: str) -> list:
    """Search exposed folders"""
    q = Query()
    q.allintitle(f"index of /{folder}")
    results = []
    for r in search(q):
        results.append(r)
    return results

def search_onlyfans(name: str) -> list:
    """Search leaks of OnlyFans.com users"""
    results = []
    for s in Site.LIST_PASTING:
        q = Query()
        q.raw(name)
        q.site(s)
        r = search(q)
        results.extend(r)
    return results


# cli.py

import click

from .wrapper import search as v_search
from .wrapper import search_onlyfans as v_onlyfans
from .wrapper import search_index_of as v_index

LINKVERTISE_MESSAGE = "---\n!!! Redirected to linkvertise.com? Use 'thebypasser.com' to bypass linkvertise links! !!!\n---"

@click.group()
def cli():
    pass

@cli.command()
@click.argument("query")
def search(query: str) -> None:
    """Search a query on Google

    Args:
        query (str): Query
    """
    results = v_search(query)
    if len(results) > 0:
        for url in results:
            print(url)
    click.echo(LINKVERTISE_MESSAGE)

@cli.command()
@click.argument("name")
def onlyfans(name: str) -> None:
    """Find leaks of onlyfans models

    Args:
        query (str): Query
    """
    results = v_onlyfans(name)
    if len(results) > 0:
        for url in results:
            print(url)
    click.echo(LINKVERTISE_MESSAGE)

@cli.command()
@click.argument("folder")
def indexof(folder: str) -> None:
    """Predefined 'index of /' search

    Args:
        folder (str): Name of folder
    """
    results = v_index(folder)
    if len(results) > 0:
        for url in results:
            print(url)
    click.echo(LINKVERTISE_MESSAGE)

if __name__ == "__main__":
    cli()


class Site:
    """Collection of some useful sites for dorking"""
    # file sharing
    GOOGLEDRIVE = "drive.google.com"
    GOFILE = "gofile.io"
    ANONFILE = "anonfile.com"
    BAYFILES = "bayfiles.com"
    # pasting
    JUSTPASTE = "justpaste.it"
    FAMOUSPASTE = "famouspaste.com"
    PASTELINK = "pastelink.net"
    NULLBIN = "0bin.net"
    RENTRY = "rentry.co"
    PASTESITE = "pastesite.org"
    FREEPASTE = "freepaste.link"
    LEAKLINKS = "leaklinks.com"
    JUSTPASTE = "justpaste.it"
    PASTEBIN = "pastebin.com"
    # lists
    LIST_FILESHARING = [GOOGLEDRIVE, GOFILE, ANONFILE, BAYFILES]
    LIST_PASTING = [JUSTPASTE, FAMOUSPASTE, PASTELINK, NULLBIN, RENTRY, PASTESITE, FREEPASTE, LEAKLINKS, JUSTPASTE, PASTEBIN]


from .engine import Engine
from .extension import Extension
from .filters import Filter
from .index import Index
from .query import Query
from .searcher import Searcher
from .sites import Site
from .wrapper import search, search_index_of, search_onlyfans